==> openrpt-3.0.0-source.tar.bz2: openrpt-3.0.0-source/MetaSQL/metasql_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it">
<defaultcodec></defaultcodec>
<context>
    <name>LogOutput</name>
    <message>
        <location filename="logoutput.ui" line="32"/>
        <source>Log Output</source>
        <translation>Registro eventi</translation>
    </message>
</context>
<context>
    <name>MQLEdit</name>
    <message>
        <location filename="mqledit.cpp" line="201"/>
        <source>Not Yet Implemented</source>
        <translation>Non implementato</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="201"/>
        <source>This function has not been implemented.</source>
        <translation>Questa funzione non è stata implementata.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="207"/>
        <source>About MetaSQL Editor</source>
        <translation>Informazioni su MetaSQL Editor</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="207"/>
        <source>About MetaSQL Editor version 2.3.0</source>
        <translation>Informazioni su MetaSQL Editor version 2.3.0</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="221"/>
        <source>Document Modified!</source>
        <translation>Documento Modificato!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="222"/>
        <source>Would you like to save your changes before continuing?</source>
        <translation>Vuoi salvare i cambiamenti prima di procedere ?</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="233"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="233"/>
        <source>Encountered an unknown response. No action will be taken.</source>
        <translation>Incontrata una risposta sconosciuta. Nessuna azione sarà intrapresa.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="248"/>
        <source>No file Specified</source>
        <translation>Nessun file specificato</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="248"/>
        <source>No file was specified to save to.</source>
        <translation>Nessun file specificato su cui salvare.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="258"/>
        <source>Error Saving file</source>
        <translation>Errore nel salvataggio del file</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="258"/>
        <source>There was an error while trying to save the file.</source>
        <translation>Errore riscontrato durante il salvataggio del file.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="353"/>
        <source>---- Parsing Query ----
</source>
        <translation>---- Analisi della Query  ----
</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="357"/>
        <source>Query parsed.</source>
        <translation>Analisi query completata.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="386"/>
        <source>ERROR: Invalid query!</source>
        <translation>ERRORE: Query non valida!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="344"/>
        <source>Not Connected</source>
        <translation>Non Connesso</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="344"/>
        <source>You must be connected to a database in order to execute a query.</source>
        <translation>Devi connetterti al database per poter eseguire la query.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="358"/>
        <source>---- Executing Query ----</source>
        <translation>---- Esecuzione della Query ----</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="381"/>
        <source>Failed to execute query.</source>
        <translation>Fallita esecuzione della query.</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="31"/>
        <source>MetaSQL Editor</source>
        <translation>MetaSQL Editor</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="87"/>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="103"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="112"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="125"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="348"/>
        <source>Database</source>
        <translation>Database</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="156"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="159"/>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="162"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="170"/>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="173"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="176"/>
        <source>Ctrl+O</source>
        <translation>Ctlr+A</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="184"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="187"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="190"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="195"/>
        <source>Save &amp;As...</source>
        <translation>Salva &amp;come...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="198"/>
        <source>Save As</source>
        <translation>Salva come</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="209"/>
        <source>&amp;Print...</source>
        <translation>Stam&amp;pa...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="212"/>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="215"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="220"/>
        <source>E&amp;xit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="223"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="234"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="237"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="240"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="245"/>
        <source>&amp;Redo</source>
        <translation>&amp;Ripeti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="248"/>
        <source>Redo</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="251"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="259"/>
        <source>&amp;Cut</source>
        <translation>&amp;Taglia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="262"/>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="265"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="273"/>
        <source>C&amp;opy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="276"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="279"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="287"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="290"/>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="293"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="301"/>
        <source>&amp;Find...</source>
        <translation>&amp;Trova...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="304"/>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="307"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="312"/>
        <source>&amp;Contents...</source>
        <translation>&amp;Contenuti...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="315"/>
        <source>Contents</source>
        <translation>Contanuti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="323"/>
        <source>&amp;Index...</source>
        <translation>&amp;Indice...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="326"/>
        <source>Index</source>
        <translation>Indice</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="334"/>
        <source>&amp;About</source>
        <translation>Informazioni s&amp;u</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="337"/>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="356"/>
        <source>Connect...</source>
        <translation>Connetti...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="364"/>
        <source>Disconnect</source>
        <translation>Disconnetti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="372"/>
        <source>Unnamed</source>
        <translation>Senza nome</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="380"/>
        <source>Parameter List...</source>
        <translation>Lista dei parametri...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="388"/>
        <source>Log Output...</source>
        <translation>Registro eventi...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="396"/>
        <source>Results...</source>
        <translation>Risultati...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="404"/>
        <source>Parse Query</source>
        <translation>Analizza Query</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="412"/>
        <source>Execute Query</source>
        <translation>Esegui Query</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="420"/>
        <source>Executed SQL...</source>
        <translation>SQL Eseguiti...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="mqledit.cpp" line="100"/>
        <source>MQLEdit for Windows</source>
        <translation>MQLEdit per Windows</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="102"/>
        <source>MQLEdit for Linux</source>
        <translation>MQLEdit per Linux</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="104"/>
        <source>MQLEdit for OS X</source>
        <translation>MQLEdit per OS X</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="106"/>
        <source>MQLEdit</source>
        <translation>MQLEdit</translation>
    </message>
    <message>
        <location filename="data.cpp" line="26"/>
        <source>Copyright (c) 2002-2008, OpenMFG, LLC.</source>
        <translation>Copyright (c) 2002-2008, OpenMFG, LLC.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="92"/>
        <source>Can not load database driver</source>
        <translation>Impossibile caricare il driver del database</translation>
    </message>
    <message>
        <location filename="main.cpp" line="92"/>
        <source>Unable to load the database driver. Please contact your systems administrator.</source>
        <translation>Impossibile caricare il driver del database. Contatta l&apos;amministratore di sistema.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="101"/>
        <source>Unable to connect to database</source>
        <translation>Impossibile connettersi al database</translation>
    </message>
    <message>
        <location filename="main.cpp" line="101"/>
        <source>Unable to connect to the database with the given information.</source>
        <translation>Impossibile connettersi al database con le informazioni specificate.</translation>
    </message>
</context>
<context>
    <name>ResultsOutput</name>
    <message>
        <location filename="resultsoutput.ui" line="32"/>
        <source>Results Output</source>
        <translation>Risultati</translation>
    </message>
</context>
</TS>

==> openrpt-3.1.0-source.tar.bz2: openrpt-3.1.0-source/MetaSQL/metasql_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>LogOutput</name>
    <message>
        <location filename="logoutput.ui" line="30"/>
        <source>Log Output</source>
        <translation>Registro eventi</translation>
    </message>
</context>
<context>
    <name>MQLEdit</name>
    <message>
        <location filename="mqledit.cpp" line="142"/>
        <location filename="mqledit.cpp" line="157"/>
        <location filename="mqledit.cpp" line="164"/>
        <location filename="mqledit.cpp" line="171"/>
        <source>Not Yet Implemented</source>
        <translation>Non implementato</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="143"/>
        <location filename="mqledit.cpp" line="158"/>
        <location filename="mqledit.cpp" line="165"/>
        <location filename="mqledit.cpp" line="172"/>
        <source>This function has not been implemented.</source>
        <translation>Questa funzione non è stata implementata.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="178"/>
        <source>About MetaSQL Editor</source>
        <translation>Informazioni su MetaSQL Editor</translation>
    </message>
    <message>
        <source>About MetaSQL Editor version 2.3.0</source>
        <translation type="obsolete">Informazioni su MetaSQL Editor version 2.3.0</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="179"/>
        <source>About MetaSQL Editor version 3.1.0</source>
        <translation>Informazioni su MetaSQL Editor version 3.1.0</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="193"/>
        <source>Document Modified!</source>
        <translation>Documento Modificato!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="194"/>
        <source>Would you like to save your changes before continuing?</source>
        <translation>Vuoi salvare i cambiamenti prima di procedere ?</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="205"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="206"/>
        <source>Encountered an unknown response. No action will be taken.</source>
        <translation>Incontrata una risposta sconosciuta. Nessuna azione sarà intrapresa.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="221"/>
        <source>No file Specified</source>
        <translation>Nessun file specificato</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="222"/>
        <source>No file was specified to save to.</source>
        <translation>Nessun file specificato su cui salvare.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="232"/>
        <source>Error Saving file</source>
        <translation>Errore nel salvataggio del file</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="233"/>
        <source>There was an error while trying to save the file.</source>
        <translation>Errore riscontrato durante il salvataggio del file.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="304"/>
        <location filename="mqledit.cpp" line="329"/>
        <source>---- Parsing Query ----
</source>
        <translation>---- Analisi della Query  ----
</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="308"/>
        <location filename="mqledit.cpp" line="333"/>
        <source>Query parsed.</source>
        <translation>Analisi query completata.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="310"/>
        <location filename="mqledit.cpp" line="361"/>
        <source>ERROR: Invalid query!</source>
        <translation>ERRORE: Query non valida!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="319"/>
        <source>Not Connected</source>
        <translation>Non Connesso</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="320"/>
        <source>You must be connected to a database in order to execute a query.</source>
        <translation>Devi connetterti al database per poter eseguire la query.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="334"/>
        <source>---- Executing Query ----</source>
        <translation>---- Esecuzione della Query ----</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="356"/>
        <source>Failed to execute query.</source>
        <translation>Fallita esecuzione della query.</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="31"/>
        <source>MetaSQL Editor</source>
        <translation>MetaSQL Editor</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="87"/>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="103"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="112"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="125"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="129"/>
        <location filename="mqledit.ui" line="345"/>
        <location filename="mqledit.ui" line="348"/>
        <source>Database</source>
        <translation>Database</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="156"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="159"/>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="162"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="170"/>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="173"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="176"/>
        <source>Ctrl+O</source>
        <translation>Ctlr+A</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="184"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="187"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="190"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="195"/>
        <source>Save &amp;As...</source>
        <translation>Salva &amp;come...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="198"/>
        <source>Save As</source>
        <translation>Salva come</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="209"/>
        <source>&amp;Print...</source>
        <translation>Stam&amp;pa...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="212"/>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="215"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="220"/>
        <source>E&amp;xit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="223"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="234"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="237"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="240"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="245"/>
        <source>&amp;Redo</source>
        <translation>&amp;Ripeti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="248"/>
        <source>Redo</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="251"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="259"/>
        <source>&amp;Cut</source>
        <translation>&amp;Taglia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="262"/>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="265"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="273"/>
        <source>C&amp;opy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="276"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="279"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="287"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="290"/>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="293"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="301"/>
        <source>&amp;Find...</source>
        <translation>&amp;Trova...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="304"/>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="307"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="312"/>
        <source>&amp;Contents...</source>
        <translation>&amp;Contenuti...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="315"/>
        <source>Contents</source>
        <translation>Contanuti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="323"/>
        <source>&amp;Index...</source>
        <translation>&amp;Indice...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="326"/>
        <source>Index</source>
        <translation>Indice</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="334"/>
        <source>&amp;About</source>
        <translation>Informazioni s&amp;u</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="337"/>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="353"/>
        <location filename="mqledit.ui" line="356"/>
        <source>Connect...</source>
        <translation>Connetti...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="361"/>
        <location filename="mqledit.ui" line="364"/>
        <source>Disconnect</source>
        <translation>Disconnetti</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="369"/>
        <location filename="mqledit.ui" line="372"/>
        <source>Unnamed</source>
        <translation>Senza nome</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="377"/>
        <location filename="mqledit.ui" line="380"/>
        <source>Parameter List...</source>
        <translation>Lista dei parametri...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="385"/>
        <location filename="mqledit.ui" line="388"/>
        <source>Log Output...</source>
        <translation>Registro eventi...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="393"/>
        <location filename="mqledit.ui" line="396"/>
        <source>Results...</source>
        <translation>Risultati...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="401"/>
        <location filename="mqledit.ui" line="404"/>
        <source>Parse Query</source>
        <translation>Analizza Query</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="409"/>
        <location filename="mqledit.ui" line="412"/>
        <source>Execute Query</source>
        <translation>Esegui Query</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="417"/>
        <location filename="mqledit.ui" line="420"/>
        <source>Executed SQL...</source>
        <translation>SQL Eseguiti...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="mqledit.cpp" line="387"/>
        <source>MQLEdit for Windows</source>
        <translation>MQLEdit per Windows</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="389"/>
        <source>MQLEdit for Linux</source>
        <translation>MQLEdit per Linux</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="391"/>
        <source>MQLEdit for OS X</source>
        <translation>MQLEdit per OS X</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="393"/>
        <source>MQLEdit</source>
        <translation>MQLEdit</translation>
    </message>
    <message>
        <location filename="data.cpp" line="25"/>
        <source>Copyright (c) 2002-2008, OpenMFG, LLC.</source>
        <translation>Copyright (c) 2002-2008, OpenMFG, LLC.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="92"/>
        <source>Can not load database driver</source>
        <translation>Impossibile caricare il driver del database</translation>
    </message>
    <message>
        <location filename="main.cpp" line="93"/>
        <source>Unable to load the database driver. Please contact your systems administrator.</source>
        <translation>Impossibile caricare il driver del database. Contatta l&apos;amministratore di sistema.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="102"/>
        <source>Unable to connect to database</source>
        <translation>Impossibile connettersi al database</translation>
    </message>
    <message>
        <location filename="main.cpp" line="103"/>
        <source>Unable to connect to the database with the given information.</source>
        <translation>Impossibile connettersi al database con le informazioni specificate.</translation>
    </message>
</context>
<context>
    <name>ResultsOutput</name>
    <message>
        <location filename="resultsoutput.ui" line="30"/>
        <source>Results Output</source>
        <translation>Risultati</translation>
    </message>
</context>
</TS>
